import { AbstractPowerSyncDatabase, AbstractPowerSyncDatabaseOpenFactory, PowerSyncDatabaseOptions, PowerSyncOpenFactoryOptions } from '@journeyapps/powersync-sdk-common';
import { WebPowerSyncDatabaseOptions } from '../../db/PowerSyncDatabase';
export type WebPowerSyncFlags = {
    enableMultiTabs?: boolean;
    disableSSRWarning?: boolean;
};
export interface WebPowerSyncOpenFactoryOptions extends PowerSyncOpenFactoryOptions {
    flags?: WebPowerSyncFlags;
}
export declare const DEFAULT_POWERSYNC_FLAGS: WebPowerSyncFlags;
/**
 * Intermediate PowerSync Database Open factory for Web which uses a mock
 * SSR DB Adapter if running on server side.
 * Most SQLite DB implementations only run on client side, this will safely return
 * empty query results in SSR which will allow for generating server partial views.
 */
export declare abstract class AbstractWebPowerSyncDatabaseOpenFactory extends AbstractPowerSyncDatabaseOpenFactory {
    protected options: WebPowerSyncOpenFactoryOptions;
    protected isServerSide(): boolean;
    constructor(options: WebPowerSyncOpenFactoryOptions);
    generateOptions(): WebPowerSyncDatabaseOptions;
    protected resolveFlags(): WebPowerSyncFlags & {
        ssrMode: boolean;
        enableMultiTabs: boolean | undefined;
        disableSSRWarning?: boolean | undefined;
    };
    generateInstance(options: PowerSyncDatabaseOptions): AbstractPowerSyncDatabase;
}
