import { BaseObserver, DBAdapter, DBAdapterListener, DBLockOptions, LockContext, PowerSyncOpenFactoryOptions, QueryResult, Transaction } from '@journeyapps/powersync-sdk-common';
export type WASQLiteFlags = {
    enableMultiTabs?: boolean;
};
export interface WASQLiteDBAdapterOptions extends Omit<PowerSyncOpenFactoryOptions, 'schema'> {
    flags?: WASQLiteFlags;
}
/**
 * Adapter for WA-SQLite
 */
export declare class WASQLiteDBAdapter extends BaseObserver<DBAdapterListener> implements DBAdapter {
    protected options: WASQLiteDBAdapterOptions;
    private initialized;
    private logger;
    private dbGetHelpers;
    private workerMethods;
    constructor(options: WASQLiteDBAdapterOptions);
    get name(): string;
    protected get flags(): WASQLiteFlags;
    protected init(): Promise<void>;
    execute(query: string, params?: any[] | undefined): Promise<QueryResult>;
    /**
     * Wraps the worker execute function, awaiting for it to be available
     */
    private _execute;
    close(): void;
    getAll<T>(sql: string, parameters?: any[] | undefined): Promise<T[]>;
    getOptional<T>(sql: string, parameters?: any[] | undefined): Promise<T | null>;
    get<T>(sql: string, parameters?: any[] | undefined): Promise<T>;
    readLock<T>(fn: (tx: LockContext) => Promise<T>, options?: DBLockOptions | undefined): Promise<T>;
    writeLock<T>(fn: (tx: LockContext) => Promise<T>, options?: DBLockOptions | undefined): Promise<T>;
    readTransaction<T>(fn: (tx: Transaction) => Promise<T>, options?: DBLockOptions | undefined): Promise<T>;
    writeTransaction<T>(fn: (tx: Transaction) => Promise<T>, options?: DBLockOptions | undefined): Promise<T>;
    /**
     * Wraps a lock context into a transaction context
     */
    private wrapTransaction;
    private generateDBHelpers;
}
