var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { AbstractRemote } from '@journeyapps/powersync-sdk-common';
export class WebRemote extends AbstractRemote {
    post(path, data, headers = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const credentials = yield this.getCredentials();
            const res = yield fetch(credentials.endpoint + path, {
                method: 'POST',
                headers: Object.assign(Object.assign({}, headers), (yield this.getHeaders())),
                body: JSON.stringify(data)
            });
            if (!res.ok) {
                throw new Error(`Received ${res.status} - ${res.statusText} when posting to ${path}: ${yield res.text()}}`);
            }
            return res.json();
        });
    }
    get(path, headers) {
        return __awaiter(this, void 0, void 0, function* () {
            const credentials = yield this.getCredentials();
            const res = yield fetch(credentials.endpoint + path, {
                method: 'GET',
                headers: Object.assign(Object.assign({}, headers), (yield this.getHeaders()))
            });
            if (!res.ok) {
                throw new Error(`Received ${res.status} - ${res.statusText} when getting from ${path}: ${yield res.text()}}`);
            }
            return res.json();
        });
    }
    postStreaming(path, data, headers = {}, signal) {
        return __awaiter(this, void 0, void 0, function* () {
            const credentials = yield this.getCredentials();
            const res = yield fetch(credentials.endpoint + path, {
                method: 'POST',
                headers: Object.assign(Object.assign({}, headers), (yield this.getHeaders())),
                body: JSON.stringify(data),
                signal,
                cache: 'no-store'
            });
            if (!res.ok) {
                const text = yield res.text();
                console.error(`Could not POST streaming to ${path} - ${res.status} - ${res.statusText}: ${text}`);
                const error = new Error(`HTTP ${res.statusText}: ${text}`);
                error.status = res.status;
                throw error;
            }
            return res.body;
        });
    }
}
//# sourceMappingURL=WebRemote.js.map